@@ -39,4 +39,8 @@ class BadRequest(Exception):
 
 class Timeout(Exception):
     def __init__(self):
-        Exception.__init__(self,"Timeout reached, try again alter")
\ No newline at end of file
+        Exception.__init__(self,"Timeout reached, try again alter")
+        
+class InvalidServer(Exception):
+    def __init__(self, current_server, accepted_servers):
+        Exception.__init__(self,"Set server is {current_server}, this endpoint only supports {accepted_servers}" .format(current_server=current_server, accepted_servers=",".join(accepted_servers)))
\ No newline at end of file
