@@ -4,16 +4,22 @@ import pytest
 from pantheon import pantheon
 from pantheon.utils import exceptions as exc
 
+import os
+
 # API details
-api_key = "RGAPI-8fa19f91-0d70-442e-ab63-3148ea28ce71"
+api_key = os.environ['PANTHEON_KEY']
 server = "euw1"
 panth = pantheon.Pantheon(server, api_key, errorHandling=True)
 
+panth_americas = pantheon.Pantheon("americas", api_key, errorHandling=True)
+panth_eu = pantheon.Pantheon("eu", api_key, errorHandling=True)
+
 # Summoner details
 name = "Canisback"
-accountId = "VRTAqAZgHiTwK90Xd9hAaRejrTD0D9n69izLSqQwKf9sug"
-summonerId = "Oizbr1dzsLM9ygEADNequ88CIRCq2wDV5EeWcxZQFWSKFvc"
-puuid = "hhH5SNlbp-0xYiernub2nxBdMeuNxQRRDcCI4bXh4xoE4bS_II1d-lemvVT3Q2Uf0ZdiJmnr0GOhBg"
+tag = "EUW1"
+accountId = "mCT1-43iYmFMG0-X2efejgX6JBnMneMnGXALxYTE_1nvaQ"
+summonerId = "r3jOCGc0_W5N9lg-ZANlC2CSEnn-7wMGm_hZAdo-bxprB_4"
+puuid = "S6OWGeKQqY-SCU8931OPdK2zmenypS5Hs_YHv6SrmBDAVMMJpDQeTq8q06tzTFHvNaXWoIf6Fm5iTg"
 
 
 # League details
@@ -21,7 +27,7 @@ leagueId = "d112cf40-35be-11e9-947f-c81f66db01ef"
 
 ## Set to True if skipping apex tiers
 too_early = False
-too_early_tft = True
+too_early_tft = False
 
 # Match details
 matchId = 4259542242
@@ -35,11 +41,16 @@ tournament_name = "Test"
 # TFT details
 tft_leagueId = "30032c60-f82a-11e9-8d92-a2a060ae885a"
 
-tft_matchId = "EUW1_4268130192"
+tft_matchId = "NA1_3525864593"
 
 loop = asyncio.get_event_loop() 
 
 # Clash data
-clash_summonerId = "xh_cze9i1PtqKQgT9WuIYkbIuC8o-koc9qPv-HHQODd-IWs"
+clash_summonerId = "r3jOCGc0_W5N9lg-ZANlC2CSEnn-7wMGm_hZAdo-bxprB_4"
 clash_teamId = "1139965"
-clash_tournamentId = 2002
\ No newline at end of file
+clash_tournamentId = 2002
+
+
+#Valorant data
+val_puuid = "zxzDtQcrVZGz4-p4e_woWLRZb-DOy2dejjYTH-nLrFgGAjHVXR_qHaOLO80l0YqpKQEo-wtbmbn10w"
+val_matchId = "f35567d8-9587-43f2-80a8-695ad45b1cf5"
\ No newline at end of file
